define(["require", "exports"], function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.CompatibleNodeType = void 0;
    /**
     * The is essentially an enum represents the type of the node
     * https://developer.mozilla.org/en-US/docs/Web/API/Node/nodeType
     * Values not listed here are deprecated.
     */
    // eslint-disable-next-line etc/no-const-enum
    var CompatibleNodeType;
    (function (CompatibleNodeType) {
        /**
         * An Element node such as &lt;p&gt; or &lt;div&gt;.
         */
        CompatibleNodeType[CompatibleNodeType["Element"] = 1] = "Element";
        /**
         * An Attribute node such as name="value".
         */
        CompatibleNodeType[CompatibleNodeType["Attribute"] = 2] = "Attribute";
        /**
         * The actual Text of Element or Attr.
         */
        CompatibleNodeType[CompatibleNodeType["Text"] = 3] = "Text";
        /**
         * A ProcessingInstruction of an XML document such as &lt;?xml-stylesheet ... ?&gt; declaration.
         */
        CompatibleNodeType[CompatibleNodeType["ProcessingInstruction"] = 7] = "ProcessingInstruction";
        /**
         * A Comment node.
         */
        CompatibleNodeType[CompatibleNodeType["Comment"] = 8] = "Comment";
        /**
         * A Document node.
         */
        CompatibleNodeType[CompatibleNodeType["Document"] = 9] = "Document";
        /**
         * A DocumentType node e.g. &lt;!DOCTYPE html&gt; for HTML5 documents.
         */
        CompatibleNodeType[CompatibleNodeType["DocumentType"] = 10] = "DocumentType";
        /**
         * A DocumentFragment node.
         */
        CompatibleNodeType[CompatibleNodeType["DocumentFragment"] = 11] = "DocumentFragment";
    })(CompatibleNodeType = exports.CompatibleNodeType || (exports.CompatibleNodeType = {}));
});
//# sourceMappingURL=NodeType.js.map