"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CompatibleEntityOperation = void 0;
/**
 * Define possible operations to an entity
 */
// eslint-disable-next-line etc/no-const-enum
var CompatibleEntityOperation;
(function (CompatibleEntityOperation) {
    /**
     * Notify plugins that there is a new plugin was added into editor.
     * Plugin can handle this event to entity hydration.
     * This event will be only fired once for each entity DOM node.
     * After undo, or copy/paste, since new DOM nodes were added, this event will be fired
     * for those entities represented by newly added nodes.
     */
    CompatibleEntityOperation[CompatibleEntityOperation["NewEntity"] = 0] = "NewEntity";
    /**
     * Notify plugins that user is clicking target to an entity
     */
    CompatibleEntityOperation[CompatibleEntityOperation["Click"] = 1] = "Click";
    /**
     * Notify plugins that user is triggering context menu to an entity
     */
    CompatibleEntityOperation[CompatibleEntityOperation["ContextMenu"] = 2] = "ContextMenu";
    /**
     * Notify plugins that user is escaping from an entity by pressing ESC key
     */
    CompatibleEntityOperation[CompatibleEntityOperation["Escape"] = 3] = "Escape";
    /**
     * Notify plugins that user is removing an entity from its start position using DELETE key
     */
    CompatibleEntityOperation[CompatibleEntityOperation["RemoveFromStart"] = 4] = "RemoveFromStart";
    /**
     * Notify plugins that user is remove an entity from its end position using BACKSPACE key
     */
    CompatibleEntityOperation[CompatibleEntityOperation["RemoveFromEnd"] = 5] = "RemoveFromEnd";
    /**
     * Notify plugins that an entity is being overwritten.
     * This can be caused by key in, cut, paste, delete, backspace ... on a selection
     * which contains some entities.
     */
    CompatibleEntityOperation[CompatibleEntityOperation["Overwrite"] = 6] = "Overwrite";
    /**
     * Notify plugins that an entity is being partially overwritten.
     * This happens when user selected part of the entity then do key press, or cut, paste, delete, backspace, ...
     */
    CompatibleEntityOperation[CompatibleEntityOperation["PartialOverwrite"] = 7] = "PartialOverwrite";
    /**
     * Notify plugins that editor is generating HTML content for save.
     * Plugin should use this event to remove any temporary content, and only leave DOM nodes that
     * should be saved as HTML string.
     * This event will provide a cloned DOM tree for each entity, do NOT compare the DOM nodes with cached nodes
     * because it will always return false.
     */
    CompatibleEntityOperation[CompatibleEntityOperation["ReplaceTemporaryContent"] = 8] = "ReplaceTemporaryContent";
    /**
     * @deprecated
     */
    CompatibleEntityOperation[CompatibleEntityOperation["AddShadowRoot"] = 9] = "AddShadowRoot";
    /**
     * @deprecated
     */
    CompatibleEntityOperation[CompatibleEntityOperation["RemoveShadowRoot"] = 10] = "RemoveShadowRoot";
    /**
     * Notify plugins that a new entity state need to be updated to an entity.
     * This is normally happened when user undo/redo the content with an entity snapshot added by a plugin that handles entity
     */
    CompatibleEntityOperation[CompatibleEntityOperation["UpdateEntityState"] = 11] = "UpdateEntityState";
})(CompatibleEntityOperation = exports.CompatibleEntityOperation || (exports.CompatibleEntityOperation = {}));
//# sourceMappingURL=EntityOperation.js.map